@@ -16,7 +16,7 @@ In emacs, you can use this by using the following sequence
 
    M-x compile RET check-page [filename] RET
 
-Which will check the page and record the errors.  You can then use 
+Which will check the page and record the errors.  You can then use
 
    M-`
 
@@ -32,7 +32,7 @@ L<suggest(1)>; L<link-report.cgi(1)>; L<configure-link-control>
 The LinkController manual in the distribution in HTML, info, or
 postscript formats, included in the distribution.
 
-http://scotclimb.org.uk/software/linkcont - the
+http://scotclimb.org.uk/software/linkcont/ - the
 LinkController homepage.
 
 =cut
@@ -47,24 +47,19 @@ use WWW::Link::Reporter::Compile;
 #eval to ignore if a file doesn't exist.. e.g. the system config
 
 use WWW::Link_Controller::ReadConf;
+use WWW::Link_Controller::InfoStruc;
+use WWW::Link_Controller::URL;
 
 
 ##############################################################################
 #start command line processing
 use Getopt::Function qw(maketrue makevalue);
 
-use vars qw($not_perfect $redirect $since); 
+use vars qw($not_perfect $redirect $since);
 
-$::ingore_missing=0;
-$::infostructure=0;
+$::redirect=0;
+$::ignore_missing=0;
 $::verbose=0;
-$::not_perfect=0;
-$::since=0;
-$::html=0;
-$::long_list=0;
-@::exclude=();
-@::include=();
-@::urls=();
 
 $::opthandler = new Getopt::Function 
   [ "version V>version",
@@ -72,10 +67,6 @@ $::opthandler = new Getopt::Function
     "help-opt=s",
     "verbose:i v>verbose",
     "",
-#    "exclude=s e>exclude",
-#    "include=s i>include",
-#    "since=s s>since",
-#    "not-perfect n>not-perfect",
     "redirect r>redirect",
     "ignore-missing m>ignore-missing",
     "",
@@ -83,19 +74,6 @@ $::opthandler = new Getopt::Function
     "link-database=s",
   ],
   {
-#       "exclude" => [ sub { push @::exclude, $::value; },
-# 		     "Add a list of regular expressions for URLs to ignore.",
-# 		     "EXCLUDE RE" ],
-#       "include" => [ sub { push @::include, $::value; },
-# 		     "Give regular expression for URLs to check (if this "
-# 		     . "option is given others aren't checked).",
-# 		     "INCLUDE RE" ],
-# 	"since" => [ \&makevalue, #FIXME process time strings
-# 		     "Only list links who's status has changed since the "
-# 		     . "given time.",
-# 		     "TIME" ],
-#   "not-perfect" => [ \&maketrue,
-# 		     "Report any url which wasn't okay at last test." ],
      "redirect" => [ \&maketrue,
 		     "Report links which are redirected." ],
   "ignore-missing" => [ \&maketrue,
@@ -116,7 +94,7 @@ $::opthandler->check_opts;
 
 sub usage() {
   print <<EOF;
-check-page.pl [options] filename...
+check-page [options] filename...
 
 EOF
   $::opthandler->list_opts;
@@ -131,35 +109,51 @@ EOF
 sub version() {
   print <<'EOF';
 check-page version 
-$Id: check-page.pl,v 1.7 2001/11/22 15:40:11 mikedlr Exp $
+$Id: check-page.pl,v 1.9 2002/02/03 21:20:41 mikedlr Exp $
 EOF
 }
 
 ##############################################################################
 #end command line processing
 
+$::default_infostrucs=1 unless defined $::default_infostrucs;
+
+die "you must define the \$::infostrucs configuration variable"
+  if $::default_infostrucs and not defined $::infostrucs ;
+
+WWW::Link_Controller::InfoStruc::default_infostrucs()
+  if $::default_infostrucs;
+
 die 'you must define the $::links configuration variable' 
     unless $::links;
+$::linkdbm = undef;
 $::linkdbm = tie %::links, "MLDBM", $::links, O_RDONLY, 0666, $DB_HASH
   or die $!;
 
-
 my $reporter = new WWW::Link::Reporter::Compile;
 $reporter->all_reports(1);
 $reporter->{"report_okay"}=0;
 
+
+my $base_url=undef;
+my $file=undef;
 $linkfunc = sub {
   my($tag, %attr) = @_;
-LINK: while (($attr, $linkname)=each %attr) {
+LINK: while (my ($attr, $linkname)=each %attr) {
     unless ( $linkname ) {
       warn "Undefined link name generated";
       next LINK;
     }
-    print STDERR "examining link $linkname\n" if 
+    my ( $uri, $fragment )
+      = WWW::Link_Controller::URL::fixup_link_url($linkname,$base_url);
+    defined $uri or do {
+      reporter->invalid($linkname);
+    };
+    print STDERR "examining link $uri\n" if
 	$::verbose & 8;
-    my $link=$::links{$linkname};
+    my $link=$::links{$uri};
     unless (defined $link) {
-      $reporter->not_found($linkname) unless $::ignore_missing;
+      $reporter->not_found($uri) unless $::ignore_missing;
       next LINK;
     }
     $reporter->examine($link);
@@ -174,11 +168,15 @@ my $p = HTML::LinkExtor->new($linkfunc);
 # we force this to work line by line..  This should mean that error
 # messages come out at the end of any tag
 
-while ( <> ) #actually this'll work on the SDIN, but why tell them..
-{
-  $p->parse($_);
-  if (eof) {
-    close(ARGV); #reset line numbers
-    $p->eof();   #force link extractor to finish
+foreach $file ( @ARGV) {
+  print STDERR "file is $file " if $::verbose;
+  $reporter->filename($file);
+  $base_url=WWW::Link_Controller::InfoStruc::file_to_url($file);
+  print STDERR "url is $base_url\n" if $::verbose;
+  open IN, $file;
+  while (my $line=<IN> ) {
+    $p->parse($line);
   }
-}	
+  close IN ; #reset line numbers
+  $p->eof();   #force link extractor to finish
+}
